﻿import 'jasmine';

import { TestBed } from '@angular/core/testing';
import * as tinymce from 'tinymce';

import { TinyEditorInlineConfiguration } from '../src/Models/tiny-editor-inline-configuration.model';

import { IvyWebModule } from 'ivy.angular.web';
import { MaterialsWidthHelper, IvyMaterialHelpersModule } from 'ivy.angular.material.helpers';
import { IvyAngularTinyEditorInlineModule } from '../ivy.angular.tiny-editor-inline.module';
import { TinyMceConfigurationService } from '../src/Services/tiny-mce-configuration.service';

describe('TinyMceConfigurationService', () => {

    // Varaiblees & Constants
    let sut: TinyMceConfigurationService;


    // Tests
    it('generateConfigs assigns values for inputs as expected', () => {

        TestBed.configureTestingModule({
            imports: [
                IvyAngularTinyEditorInlineModule,
                IvyMaterialHelpersModule.forRoot(),
                IvyWebModule
            ]
        });

        sut = TestBed.get(TinyMceConfigurationService);

        let widthHelper = TestBed.get(MaterialsWidthHelper);
        spyOn(widthHelper, 'isXs').and.returnValue(false);

        let elementId = 'elementId';
        let setupFn: (editor: tinymce.Editor) => void = (editor: tinymce.Editor) => {
            console.log('Setup Fn');
        };

        let result = sut.generateConfigs(elementId, setupFn);

        expect(result.selector).toBe('#' + elementId);
        expect(result.inline).toBe(true);
        expect(result.insert_toolbar).toBe('');
        expect(result.setup).toBe(setupFn);
        expect(result.theme).toBe('modern');

        expect(result.content_css).toBeUndefined();
        expect(result.plugins).toBeUndefined();
        expect(result.menubar).toBeUndefined();
        expect(result.toolbar).toBeUndefined();
    });

    it('generateConfigs assigngs theme as inlite if matWidthHelper isXs()', () => {

        TestBed.configureTestingModule({
            imports: [
                IvyAngularTinyEditorInlineModule,
                IvyMaterialHelpersModule.forRoot(),
                IvyWebModule
            ]
        });

        sut = TestBed.get(TinyMceConfigurationService);

        let widthHelper = TestBed.get(MaterialsWidthHelper);
        spyOn(widthHelper, 'isXs').and.returnValue(true);

        let elementId = 'elementId';
        let setupFn: (editor: tinymce.Editor) => void = (editor: tinymce.Editor) => {
            console.log('Setup Fn');
        };

        let result = sut.generateConfigs(elementId, setupFn);

        expect(result.selector).toBe('#' + elementId);
        expect(result.inline).toBe(true);
        expect(result.insert_toolbar).toBe('');
        expect(result.setup).toBe(setupFn);
        expect(result.theme).toBe('inlite');

        expect(result.content_css).toBeUndefined();
        expect(result.plugins).toBeUndefined();
        expect(result.menubar).toBeUndefined();
        expect(result.toolbar).toBeUndefined();
    });

    it('generateConfigs assigns optional config values appropriately', () => {

        let config: TinyEditorInlineConfiguration = new TinyEditorInlineConfiguration();

        config.cssLocation = 'testLocation';
        config.plugins = 'plugins';
        config.menubar = 'menubar';
        config.toolbar = 'toolbar';

        TestBed.configureTestingModule({
            imports: [
                IvyAngularTinyEditorInlineModule,
                IvyMaterialHelpersModule.forRoot(),
                IvyWebModule
            ],
            providers: [
                { provide: 'TinyEditorInlineConfiguration', useValue: config }
            ]
        });

        sut = TestBed.get(TinyMceConfigurationService);


        let widthHelper = TestBed.get(MaterialsWidthHelper);
        spyOn(widthHelper, 'isXs').and.returnValue(false);

        let elementId = 'elementId';
        let setupFn: (editor: tinymce.Editor) => void = (editor: tinymce.Editor) => {
            console.log('Setup Fn');
        };

        let result = sut.generateConfigs(elementId, setupFn);

        expect(result.selector).toBe('#' + elementId);
        expect(result.inline).toBe(true);
        expect(result.insert_toolbar).toBe('');
        expect(result.setup).toBe(setupFn);
        expect(result.theme).toBe('modern');

        expect(result.content_css).toBe(config.cssLocation);
        expect(result.plugins).toBe(config.plugins);
        expect(result.menubar).toBe(config.menubar);
        expect(result.toolbar).toBe(config.toolbar);
    });
});